/**
    @file ft51_mtp_registers.h

    @brief MTP registers library

    Defines registers and bit-masks for the on-chip Multi-Time Programmable
    memory.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_MTP_REGISTERS_H__
#define __FT51_MTP_REGISTERS_H__

//------------------------------------------------------------------------------
// Register 43 (0x2B) MTP_CONTROL
#define MTP_CONTROL                        0x2B

// Register 43 Bit Definitions
#define BIT_MTP_MEM_WR_FAILURE                4                                 // mtp write timeout indicating a write failure
#define MASK_MTP_MEM_WR_FAILURE               (0x1 << BIT_MTP_MEM_WR_FAILURE)
#define BIT_MTP_BYTE_PROG_DONE                5                                 // mtp byte write complete
#define MASK_MTP_BYTE_PROG_DONE               (0x1 << BIT_MTP_BYTE_PROG_DONE)
#define BIT_FLASH_MTP_MEM                     6                                 // Copy the contents of the shadow ram to MTP
#define MASK_FLASH_MTP_MEM                    (0x1 << BIT_FLASH_MTP_MEM)
#define BIT_COPY_MTP_2_RAM                    7                                 // Copy the contents of the MTP to shadow ram
#define MASK_COPY_MTP_2_RAM                   (0x1 << BIT_COPY_MTP_2_RAM)

//------------------------------------------------------------------------------
// Register 44 (0x2C) MTP_ADDR_L
#define MTP_ADDR_L                   0x2C

// Register 44 Bit Definitions
#define BIT_MTP_PROG_ADDR_L_0                 0                                 // Lower 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_L_0                (0x1 << BIT_MTP_PROG_ADDR_L_0)
#define BIT_MTP_PROG_ADDR_L_1                 1                                 // Lower 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_L_1                (0x1 << BIT_MTP_PROG_ADDR_L_1)
#define BIT_MTP_PROG_ADDR_L_2                 2                                 // Lower 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_L_2                (0x1 << BIT_MTP_PROG_ADDR_L_2)
#define BIT_MTP_PROG_ADDR_L_3                 3                                 // Lower 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_L_3                (0x1 << BIT_MTP_PROG_ADDR_L_3)
#define BIT_MTP_PROG_ADDR_L_4                 4                                 // Lower 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_L_4                (0x1 << BIT_MTP_PROG_ADDR_L_4)
#define BIT_MTP_PROG_ADDR_L_5                 5                                 // Lower 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_L_5                (0x1 << BIT_MTP_PROG_ADDR_L_5)
#define BIT_MTP_PROG_ADDR_L_6                 6                                 // Lower 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_L_6                (0x1 << BIT_MTP_PROG_ADDR_L_6)
#define BIT_MTP_PROG_ADDR_L_7                 7                                 // Lower 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_L_7                (0x1 << BIT_MTP_PROG_ADDR_L_7)
#define MASK_MTP_PROG_ADDR_L                  (0xFF << BIT_MTP_PROG_ADDR_L_0)

//------------------------------------------------------------------------------
// Register 45 (0x2D) MTP_ADDR_U
#define MTP_ADDR_U                   0x2D

// Register 45 Bit Definitions
#define BIT_MTP_PROG_ADDR_U_0                 0                                 // Upper 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_U_0                (0x1 << BIT_MTP_PROG_ADDR_U_0)
#define BIT_MTP_PROG_ADDR_U_1                 1                                 // Upper 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_U_1                (0x1 << BIT_MTP_PROG_ADDR_U_1)
#define BIT_MTP_PROG_ADDR_U_2                 2                                 // Upper 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_U_2                (0x1 << BIT_MTP_PROG_ADDR_U_2)
#define BIT_MTP_PROG_ADDR_U_3                 3                                 // Upper 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_U_3                (0x1 << BIT_MTP_PROG_ADDR_U_3)
#define BIT_MTP_PROG_ADDR_U_4                 4                                 // Upper 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_U_4                (0x1 << BIT_MTP_PROG_ADDR_U_4)
#define BIT_MTP_PROG_ADDR_U_5                 5                                 // Upper 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_U_5                (0x1 << BIT_MTP_PROG_ADDR_U_5)
#define BIT_MTP_PROG_ADDR_U_6                 6                                 // Upper 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_U_6                (0x1 << BIT_MTP_PROG_ADDR_U_6)
#define BIT_MTP_PROG_ADDR_U_7                 7                                 // Upper 8 bits of address of MTP memory to be programmed
#define MASK_MTP_PROG_ADDR_U_7                (0x1 << BIT_MTP_PROG_ADDR_U_7)
#define MASK_MTP_PROG_ADDR_U                  (0xFF << BIT_MTP_PROG_ADDR_U_0)

//------------------------------------------------------------------------------
// Register 46 (0x2E) MTP_PROG_DATA
#define MTP_PROG_DATA                     0x2E

// Register 46 Bit Definitions
#define BIT_MTP_PROG_DATA_0                   0                                 // Data to be programmed into MTP memory above
#define MASK_MTP_PROG_DATA_0                  (0x1 << BIT_MTP_PROG_DATA_0)
#define BIT_MTP_PROG_DATA_1                   1                                 // Data to be programmed into MTP memory above
#define MASK_MTP_PROG_DATA_1                  (0x1 << BIT_MTP_PROG_DATA_1)
#define BIT_MTP_PROG_DATA_2                   2                                 // Data to be programmed into MTP memory above
#define MASK_MTP_PROG_DATA_2                  (0x1 << BIT_MTP_PROG_DATA_2)
#define BIT_MTP_PROG_DATA_3                   3                                 // Data to be programmed into MTP memory above
#define MASK_MTP_PROG_DATA_3                  (0x1 << BIT_MTP_PROG_DATA_3)
#define BIT_MTP_PROG_DATA_4                   4                                 // Data to be programmed into MTP memory above
#define MASK_MTP_PROG_DATA_4                  (0x1 << BIT_MTP_PROG_DATA_4)
#define BIT_MTP_PROG_DATA_5                   5                                 // Data to be programmed into MTP memory above
#define MASK_MTP_PROG_DATA_5                  (0x1 << BIT_MTP_PROG_DATA_5)
#define BIT_MTP_PROG_DATA_6                   6                                 // Data to be programmed into MTP memory above
#define MASK_MTP_PROG_DATA_6                  (0x1 << BIT_MTP_PROG_DATA_6)
#define BIT_MTP_PROG_DATA_7                   7                                 // Data to be programmed into MTP memory above
#define MASK_MTP_PROG_DATA_7                  (0x1 << BIT_MTP_PROG_DATA_7)
#define MASK_MTP_PROG_DATA                    (0xFF << BIT_MTP_PROG_DATA_0)

//------------------------------------------------------------------------------
// Register 54 (0x36) MTP_CRC_CTRL
#define MTP_CRC_CTRL                          0x36

// Register 54 Bit Definitions
#define BIT_MTP_CRC_ENABLE                    4                                 // Write a 1 to start the CRC check on the MTP. It will be cleared remotely by the CRC block when it has completed.
#define MASK_MTP_CRC_ENABLE                   (0x1 << BIT_MTP_CRC_ENABLE)

//------------------------------------------------------------------------------
// Register 55 (0x37) MTP_CRC_RESULT_L
#define MTP_CRC_RESULT_L                      0x37

// Register 55 Bit Definitions
#define BIT_MTP_CRC_LOWER_BYTE_0              0                                 // Lower byte of CRC result
#define MASK_MTP_CRC_LOWER_BYTE_0             (0x1 << BIT_MTP_CRC_LOWER_BYTE_0)
#define BIT_MTP_CRC_LOWER_BYTE_1              1                                 // Lower byte of CRC result
#define MASK_MTP_CRC_LOWER_BYTE_1             (0x1 << BIT_MTP_CRC_LOWER_BYTE_1)
#define BIT_MTP_CRC_LOWER_BYTE_2              2                                 // Lower byte of CRC result
#define MASK_MTP_CRC_LOWER_BYTE_2             (0x1 << BIT_MTP_CRC_LOWER_BYTE_2)
#define BIT_MTP_CRC_LOWER_BYTE_3              3                                 // Lower byte of CRC result
#define MASK_MTP_CRC_LOWER_BYTE_3             (0x1 << BIT_MTP_CRC_LOWER_BYTE_3)
#define BIT_MTP_CRC_LOWER_BYTE_4              4                                 // Lower byte of CRC result
#define MASK_MTP_CRC_LOWER_BYTE_4             (0x1 << BIT_MTP_CRC_LOWER_BYTE_4)
#define BIT_MTP_CRC_LOWER_BYTE_5              5                                 // Lower byte of CRC result
#define MASK_MTP_CRC_LOWER_BYTE_5             (0x1 << BIT_MTP_CRC_LOWER_BYTE_5)
#define BIT_MTP_CRC_LOWER_BYTE_6              6                                 // Lower byte of CRC result
#define MASK_MTP_CRC_LOWER_BYTE_6             (0x1 << BIT_MTP_CRC_LOWER_BYTE_6)
#define BIT_MTP_CRC_LOWER_BYTE_7              7                                 // Lower byte of CRC result
#define MASK_MTP_CRC_LOWER_BYTE_7             (0x1 << BIT_MTP_CRC_LOWER_BYTE_7)
#define MASK_MTP_CRC_LOWER_BYTE               (0xFF << BIT_MTP_CRC_LOWER_BYTE_0)

//------------------------------------------------------------------------------
// Register 56 (0x38) MTP_CRC_RESULT_U
#define MTP_CRC_RESULT_U                      0x38

// Register 56 Bit Definitions
#define BIT_MTP_CRC_UPPER_BYTE_0              0                                 // Upper byte of CRC result
#define MASK_MTP_CRC_UPPER_BYTE_0             (0x1 << BIT_MTP_CRC_UPPER_BYTE_0)
#define BIT_MTP_CRC_UPPER_BYTE_1              1                                 // Upper byte of CRC result
#define MASK_MTP_CRC_UPPER_BYTE_1             (0x1 << BIT_MTP_CRC_UPPER_BYTE_1)
#define BIT_MTP_CRC_UPPER_BYTE_2              2                                 // Upper byte of CRC result
#define MASK_MTP_CRC_UPPER_BYTE_2             (0x1 << BIT_MTP_CRC_UPPER_BYTE_2)
#define BIT_MTP_CRC_UPPER_BYTE_3              3                                 // Upper byte of CRC result
#define MASK_MTP_CRC_UPPER_BYTE_3             (0x1 << BIT_MTP_CRC_UPPER_BYTE_3)
#define BIT_MTP_CRC_UPPER_BYTE_4              4                                 // Upper byte of CRC result
#define MASK_MTP_CRC_UPPER_BYTE_4             (0x1 << BIT_MTP_CRC_UPPER_BYTE_4)
#define BIT_MTP_CRC_UPPER_BYTE_5              5                                 // Upper byte of CRC result
#define MASK_MTP_CRC_UPPER_BYTE_5             (0x1 << BIT_MTP_CRC_UPPER_BYTE_5)
#define BIT_MTP_CRC_UPPER_BYTE_6              6                                 // Upper byte of CRC result
#define MASK_MTP_CRC_UPPER_BYTE_6             (0x1 << BIT_MTP_CRC_UPPER_BYTE_6)
#define BIT_MTP_CRC_UPPER_BYTE_7              7                                 // Upper byte of CRC result
#define MASK_MTP_CRC_UPPER_BYTE_7             (0x1 << BIT_MTP_CRC_UPPER_BYTE_7)
#define MASK_MTP_CRC_UPPER_BYTE               (0xFF << BIT_MTP_CRC_UPPER_BYTE_0)

#endif // __FT51_MTP_REGISTERS_H__
