/**
    @file ft51_general_config_get_system_clock.c

    @brief General Configuration Library API get system clock function.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */
#include <stdlib.h>
#include "ft51_general_config.h"
#include "ft51_io_registers.h"
#include "registers/ft51_registers.h"

/**
 @brief          get_system_clock
 @details        Gets the current value of the system clock
 either 6, 12, 24, or 48 MHz.

 @return         Current frequency of the system clock.
 **/
FT51_SYSTEM_CLOCK get_system_clock(void)
{
    FT51_SYSTEM_CLOCK data = MASK_CLK_SYS_DIVISOR;

    /*
     Get only bits 1 and 2 of the TOP_CLK_SYS_DIVISOR register.
     Bits 2..1 : 0 = 48MHz
     1 = 24MHz
     2 = 12MHz
     3 = 6MHz
     */
    IO_REG_GENERAL_READ(SYSTEM_CLOCK_DIVIDER, data);

    switch (data)
    {
    default:
    case 0x00:
        return FT51_48MHZ;
    case 0x02:
        return FT51_24MHZ;
    case 0x04:
        return FT51_12MHZ;
    case 0x06:
        return FT51_6MHZ;
    }
}