/**
    @file ft51_uart_set_baud_rate.c

    @brief UART Library API set baud rate function.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */
#include <stdint.h>

#include "ft51.h"
#include "ft51_general_config.h"
#include "ft51_uart.h"
#include "ft51_io_registers.h"
#include "registers/ft51_uart_registers.h"



void UART_set_baud_rate(uint32_t baud_rate)
{
    uint32_t  baud_factor;
    uint32_t  clock_freq = (uint32_t)get_system_clock();

    if (baud_rate == 0)
        return; // Avoid division by zero.

    baud_factor = (clock_freq * (uint32_t)1000000) / baud_rate;

    IO_REG_GENERAL_WRITE(UART_BAUD_0, (uint8_t)((baud_factor      ) & 0xFF));
    IO_REG_GENERAL_WRITE(UART_BAUD_1, (uint8_t)((baud_factor >>  8) & 0xFF));
    IO_REG_GENERAL_WRITE(UART_BAUD_2, (uint8_t)((baud_factor >> 16) & 0xFF));

    // Examples.
    // 9600 baud at 48 MHz system clock: 
    //     48 000 000 / 9 600  ==  5 000  ==  0x00001388, so
    //     BAUD_0 is 88, BAUD_1 is 13, BAUD_2 is 00.
    // 150 baud at 12 MHz system clock: 
    //     12 000 000 / 150  ==  80 000  ==  0x00013880, so
    //     BAUD_0 is 80, BAUD_1 is 38, BAUD_2 is 01.
}